@@ -145,6 +145,10 @@ def extract(
         # of documents that we won't be using, potentially using up a lot of CPU
         # time. To address this, we add another random sampling method that
         # looks for specific 'uid' field prefixes
+        if "bool" not in query["query"]:
+            query["query"]["bool"] = {}
+        if "filter" not in query["query"]["bool"]:
+            query["query"]["bool"]["filter"] = []
         query["query"]["bool"]["filter"].append(
             {
                 "bool": {
